@@ -1,5 +1,6 @@
 #include <errno.h>
 #include <string.h>
+#include <stdio.h>
 #include <locale.h>
 #include <sys/stat.h>
 
@@ -28,9 +29,9 @@ static xmlXPathCompExprPtr optionGroupsXPath;
 static xmlChar *_XklNodeGetXmlLangAttr( xmlNodePtr nptr )
 {
   if( nptr->properties != NULL &&
-      !strcmp( "lang", nptr->properties[0].name ) &&
+      !strcmp( "lang", (char *)nptr->properties[0].name ) &&
       nptr->properties[0].ns != NULL &&
-      !strcmp( "xml", nptr->properties[0].ns->prefix ) &&
+      !strcmp( "xml", (char *)nptr->properties[0].ns->prefix ) &&
       nptr->properties[0].children != NULL )
     return nptr->properties[0].children->content;
   else
@@ -55,10 +56,11 @@ static Bool _XklReadConfigItem( xmlNodePtr iptr, XklConfigItemPtr pci )
     switch ( ptr->type )
     {
       case XML_ELEMENT_NODE:
-        if( !strcmp( ptr->name, "configItem" ) )
+        if( !strcmp( (char *)ptr->name, "configItem" ) )
           break;
         return False;
       case XML_TEXT_NODE:
+      case XML_COMMENT_NODE:
         ptr = ptr->next;
         continue;
       default:
@@ -84,51 +86,59 @@ static Bool _XklReadConfigItem( xmlNodePtr iptr, XklConfigItemPtr pci )
 
       if( lang != NULL )
       {
-        int priority = _XklGetLanguagePriority( lang );
-        if( !strcmp( nptr->name, "description" ) && ( priority > maxDescPriority ) )    // higher priority
+        int priority = _XklGetLanguagePriority( (char *)lang );
+        if( !strcmp( (char *)nptr->name, "description" ) && ( priority > maxDescPriority ) )    /* higher priority */
         {
           descElement = nptr;
           maxDescPriority = priority;
-        } else if( !strcmp( nptr->name, "shortDescription" ) && ( priority > maxShortDescPriority ) )   // higher priority
+        } else if( !strcmp( (char *)nptr->name, "shortDescription" ) && ( priority > maxShortDescPriority ) )   /* higher priority */
         {
           shortDescElement = nptr;
           maxShortDescPriority = priority;
         }
       } else
       {
-        if( !strcmp( nptr->name, "description" ) )
+        if( !strcmp( (char *)nptr->name, "description" ) )
           ntDescElement = nptr;
-        else if( !strcmp( nptr->name, "shortDescription" ) )
+        else if( !strcmp( (char *)nptr->name, "shortDescription" ) )
           ntShortDescElement = nptr;
       }
     }
     nptr = nptr->next;
   }
 
-  // if no language-specific description found - use the ones without lang
+  /* if no language-specific description found - use the ones without lang */
   if( descElement == NULL )
     descElement = ntDescElement;
 
   if( shortDescElement == NULL )
     shortDescElement = ntShortDescElement;
 
-  //
-  // Actually, here we should have some code to find the correct localized description...
-  // 
+  /**
+   * Actually, here we should have some code to find the correct localized description...
+   */ 
 
   if( nameElement != NULL && nameElement->children != NULL )
-    strncat( pci->name, nameElement->children->content,
+    strncat( pci->name, (char *)nameElement->children->content,
              XKL_MAX_CI_NAME_LENGTH - 1 );
 
   if( shortDescElement != NULL && shortDescElement->children != NULL )
+  {
+    char * lsd = _XklLocaleFromUtf8( (const char *)shortDescElement->children->content );
     strncat( pci->shortDescription,
-             _XklLocaleFromUtf8( shortDescElement->children->content ),
+             lsd,
              XKL_MAX_CI_SHORT_DESC_LENGTH - 1 );
+    free( lsd );
+  }
 
   if( descElement != NULL && descElement->children != NULL )
+  {
+    char * ld = _XklLocaleFromUtf8( (const char *)descElement->children->content );
     strncat( pci->description,
-             _XklLocaleFromUtf8( descElement->children->content ),
+             ld,
              XKL_MAX_CI_DESC_LENGTH - 1 );
+    free( ld );
+  }
   return True;
 }
 
@@ -176,7 +186,7 @@ static void _XklConfigEnumDirect( const char *format,
   if( !_XklConfigRegistryIsInitialized(  ) )
     return;
   snprintf( xpathExpr, sizeof xpathExpr, format, value );
-  xpathObj = xmlXPathEval( xpathExpr, theRegistry.xpathContext );
+  xpathObj = xmlXPathEval( (unsigned char *)xpathExpr, theRegistry.xpathContext );
   if( xpathObj != NULL )
   {
     _XklConfigEnumFromNodeSet( xpathObj->nodesetval, func, userData );
@@ -198,7 +208,7 @@ static Bool _XklConfigFindObject( const char *format,
     return False;
 
   snprintf( xpathExpr, sizeof xpathExpr, format, arg1, ptr->name );
-  xpathObj = xmlXPathEval( xpathExpr, theRegistry.xpathContext );
+  xpathObj = xmlXPathEval( (unsigned char *)xpathExpr, theRegistry.xpathContext );
   if( xpathObj == NULL )
     return False;
 
@@ -294,7 +304,7 @@ void _XklConfigRecSplitByComma( char ***array,
   if( merged == NULL || merged[0] == '\0' )
     return;
 
-  // first count the elements 
+  /* first count the elements */
   while( ( npc = strchr( pc, ',' ) ) != NULL )
   {
     ( *arraySize )++;
@@ -312,7 +322,7 @@ void _XklConfigRecSplitByComma( char ***array,
     while( ( npc = strchr( pc, ',' ) ) != NULL )
     {
       int len = npc - pc;
-      //*ppc = ( char * ) strndup( pc, len );
+      /* *ppc = ( char * ) strndup( pc, len ); */
       *ppc = ( char * ) malloc( len + 1 );
       if ( *ppc != NULL )
       {
@@ -324,23 +334,45 @@ void _XklConfigRecSplitByComma( char ***array,
       pc = npc + 1;
     }
 
-    //len = npc - pc;
+    /* len = npc - pc; */
     len = strlen( pc );
-    //*ppc = ( char * ) strndup( pc, len );
+    /* *ppc = ( char * ) strndup( pc, len ); */
     *ppc = ( char * ) malloc( len + 1 );
     if ( *ppc != NULL )
       strcpy( *ppc, pc );
   }
 }
 
+char* _XklGetRulesSetName( const char defaultRuleset[] )
+{
+  static char rulesSetName[1024] = "";
+  if ( !rulesSetName[0] )
+  {
+    char* rf = NULL;
+    if( !XklGetNamesProp( xklVTable->baseConfigAtom, &rf, NULL ) || ( rf == NULL ) )
+    {
+      strncpy( rulesSetName, defaultRuleset, sizeof rulesSetName );
+      XklDebug( 100, "Using default rules set: [%s]\n", rulesSetName );
+      return rulesSetName;
+    }
+    strncpy( rulesSetName, rf, sizeof rulesSetName );
+    free( rf );
+  }
+  XklDebug( 100, "Rules set: [%s]\n", rulesSetName );
+  return rulesSetName;
+}
+
 void XklConfigInit( void )
 {
   xmlXPathInit(  );
-  modelsXPath = xmlXPathCompile( "/xkbConfigRegistry/modelList/model" );
-  layoutsXPath = xmlXPathCompile( "/xkbConfigRegistry/layoutList/layout" );
+  modelsXPath = xmlXPathCompile( (unsigned char *)"/xkbConfigRegistry/modelList/model" );
+  layoutsXPath = xmlXPathCompile( (unsigned char *)"/xkbConfigRegistry/layoutList/layout" );
   optionGroupsXPath =
-    xmlXPathCompile( "/xkbConfigRegistry/optionList/group" );
+    xmlXPathCompile( (unsigned char *)"/xkbConfigRegistry/optionList/group" );
   _XklI18NInit(  );
+
+  _XklEnsureVTableInited();
+  (*xklVTable->xklConfigInitHandler)();
 }
 
 void XklConfigTerm( void )
@@ -424,10 +456,10 @@ void XklConfigEnumOptionGroups( GroupProcessFunc func, void *userData )
       {
         Bool allowMC = True;
         xmlChar *allowMCS =
-          xmlGetProp( *theNodePtr, "allowMultipleSelection" );
+          xmlGetProp( *theNodePtr, (unsigned char *)"allowMultipleSelection" );
         if( allowMCS != NULL )
         {
-          allowMC = strcmp( "false", allowMCS );
+          allowMC = strcmp( "false", (char *)allowMCS );
           xmlFree( allowMCS );
         }
 
@@ -485,11 +517,11 @@ Bool XklConfigFindOptionGroup( XklConfigItemPtr ptr /* in/out */ ,
 
   if( rv && allowMultipleSelection != NULL )
   {
-    xmlChar *val = xmlGetProp( node, "allowMultipleSelection" );
+    xmlChar *val = xmlGetProp( node, (unsigned char *)"allowMultipleSelection" );
     *allowMultipleSelection = False;
     if( val != NULL )
     {
-      *allowMultipleSelection = !strcmp( val, "true" );
+      *allowMultipleSelection = !strcmp( (char *)val, "true" );
       xmlFree( val );
     }
   }
@@ -505,3 +537,57 @@ Bool XklConfigFindOption( const char *optionGroupName,
       "[../configItem/name = '%s' and configItem/name = '%s']",
       optionGroupName, ptr, NULL );
 }
+
+/**
+ * Calling through vtable
+ */
+Bool XklConfigActivate( const XklConfigRecPtr data )
+{
+  _XklEnsureVTableInited();
+  return (*xklVTable->xklConfigActivateHandler)( data );
+}
+
+Bool XklConfigLoadRegistry( void )
+{
+  _XklEnsureVTableInited();
+  return (*xklVTable->xklConfigLoadRegistryHandler)();
+}
+
+Bool XklConfigWriteFile( const char *fileName,
+                         const XklConfigRecPtr data,
+                         const Bool binary )
+{
+  if( ( !binary && 
+        !( xklVTable->features & XKLF_CAN_OUTPUT_CONFIG_AS_ASCII ) ) ||
+      ( binary && 
+        !( xklVTable->features & XKLF_CAN_OUTPUT_CONFIG_AS_BINARY ) ) )
+  {
+    _xklLastErrorMsg = "Function not supported at backend";
+    return False;
+  }
+  _XklEnsureVTableInited();
+  return (*xklVTable->xklConfigWriteFileHandler)( fileName, data, binary );
+}
+
+void XklConfigDump( FILE* file,
+                    XklConfigRecPtr data )
+{
+  int i,j;
+  char**p;
+  fprintf( file, "  model: [%s]\n", data->model );
+
+  fprintf( file, "  layouts(%d):\n", data->numLayouts );
+  p = data->layouts;
+  for( i = data->numLayouts, j = 0; --i >= 0; )
+    fprintf( file, "  %d: [%s]\n", j++, *p++ );
+
+  fprintf( file, "  variants(%d):\n", data->numVariants );
+  p = data->variants;
+  for( i = data->numVariants, j = 0; --i >= 0; )
+    fprintf( file, "  %d: [%s]\n", j++, *p++ );
+
+  fprintf( file, "  options(%d):\n", data->numOptions );
+  p = data->options;
+  for( i = data->numOptions, j = 0; --i >= 0; )
+    fprintf( file, "  %d: [%s]\n", j++, *p++ );
+}
