@@ -27,6 +27,8 @@ typedef unsigned ( *XklGetNumGroupsHandler )( void );
 
 typedef void ( *XklGetRealStateHandler)( XklState * curState_return );
 
+typedef Bool ( *XklIfCachedInfoEqualsActualHandler) ( void );
+
 typedef Bool ( *XklLoadAllInfoHandler )( void );
 
 typedef void ( *XklLockGroupHandler )( int group );
@@ -119,6 +121,13 @@ typedef struct
    */
   XklGetRealStateHandler xklGetRealStateHandler;
 
+  /**
+   * Compares the cached info with the actual one, from the server
+   * xkb: Compares some parts of XkbDescPtr
+   * xmodmap: returns False
+   */
+  XklIfCachedInfoEqualsActualHandler xklIfCachedInfoEqualsActualHandler;
+
   /**
    * Loads the configuration info from the server
    * xkb: loads XkbDesc, names, indicators
@@ -199,6 +208,7 @@ extern void _XklErrHandler( Display * dpy, XErrorEvent * evt );
 extern Window _XklGetRegisteredParent( Window win );
 extern Bool _XklLoadAllInfo( void );
 extern void _XklFreeAllInfo( void );
+extern void _XklResetAllInfo( const char reason[] );
 extern Bool _XklLoadWindowTree( void );
 extern Bool _XklLoadSubtree( Window window, int level, XklState * initState );
 
@@ -217,7 +227,7 @@ extern Status _XklStatusQueryTree( Display * display,
                                    Window * root_return,
                                    Window * parent_return,
                                    Window ** children_return,
-                                   signed int *nchildren_return );
+                                   unsigned int *nchildren_return );
 
 extern Bool _XklSetIndicator( int indicatorNum, Bool set );
 
@@ -259,7 +269,7 @@ extern void _XklConfigRecSplitOptions( XklConfigRecPtr data,
 extern void XklConfigDump( FILE* file,
                            XklConfigRecPtr data );
                            
-extern const char *_XklGetEventName( int type );
+extern const char *_XklGetEventName( int requestId );
 
 extern Bool _XklIsTransparentAppWindow( Window appWin );
 
